##  Single- and Multi-Select Fields
For single- and multi-select fields, ensure you enter the exact technical keys for a successful import. Separate different values with a semicolon (;), and avoid spaces before or after the semicolon.
**Tip**
When you have included single- and multi-select fields as columns in the import template, you can find the exact technical keys in the [ReadMe Sheet in Template](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a86917a441014872eecad909f5e9e__readme_sheet_in_template).
